## 1.17.8.4 (2023-06-29)

[stubsabot] Mark annoy as obsolete since 1.17.1 (#10374)

Release: https://pypi.org/pypi/annoy/1.17.1
Homepage: https://github.com/spotify/annoy
Diff: https://github.com/spotify/annoy/compare/v1.17.0...v1.17.1

Co-authored-by: stubsabot <>

## 1.17.8.3 (2023-03-27)

Add defaults for third-party stubs A-D (#9952)

## 1.17.8.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.17.8.1 (2022-11-06)

Remove `annoy` from pyright excludelist (#9114)

## 1.17.8 (2022-07-19)

Add missing third party modules (#8321)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: hauntsaninja <>
Co-authored-by: pre-commit-ci[bot] <66853113+pre-commit-ci[bot]@users.noreply.github.com>

## 1.17.7 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 1.17.6 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 1.17.4 (2021-10-12)

Add star to all non-0.1 versions (#6146)

